@@ -414,6 +414,14 @@ class Connection:
     def status_url(self):
         return self.sesamapi_base_url + "status"
 
+    @property
+    def ping_url(self):
+        return self.sesamapi_base_url + "ping"
+
+    @property
+    def admin_url(self):
+        return self.sesamapi_base_url + "admin"
+
     @property
     def node_metadata_url(self):
         return self.sesamapi_base_url + "metadata"
@@ -460,6 +468,25 @@ class Connection:
     def get_dataset_indexes_url(self, dataset_id):
         return self.get_dataset_url(dataset_id) + "/indexes"
 
+    def restart_node(self, force=False):
+        """
+            restarts the node via the admin api, it returns a dict {"message": "OK"} if successful
+        """
+
+        url = self.admin_url
+
+        postdata = {"operation": "restart"}
+
+        if force is True:
+            postdata["force"] = True
+
+        _allowable_response_status_codes = [200]
+        restart_response = self.do_post_request(url, allowable_response_status_codes=_allowable_response_status_codes,
+                                                data=postdata)
+
+        validate_response_is_ok(restart_response, allowable_response_status_codes=_allowable_response_status_codes)
+        return utils.parse_json_response(restart_response)
+
     def get_systems(self, include_internal_systems=False):
         systems = []
 
@@ -518,6 +545,13 @@ class Connection:
         status_response = self.do_get_request(self.status_url)
         return utils.parse_json_response(status_response)
 
+    def get_ping(self):
+        """
+        :return: A dict with {"status": "running"} if successful
+        """
+        status_response = self.do_get_request(self.ping_url)
+        return utils.parse_json_response(status_response)
+
     def get_datasets(self, include_internal_datasets=True, verbose=False):
         # Note: the default for getting datasets is to get all
         # including the internal ones
