@@ -4,6 +4,7 @@ import copy
 import logging
 
 import io
+import time
 
 from . import entity_json
 from .exceptions import ConfigUploadFailed
@@ -151,3 +152,14 @@ class Pipe(EntityBase):
             raise ConfigUploadFailed(response=response)
 
         self.update_raw_jsondata(response.content.decode("utf-8"))
+
+    def wait_for_pipe_to_be_deployed(self, timeout=60):
+        starttime = time.monotonic()
+        while True:
+            self.update_raw_jsondata_from_url(self._connection.get_pipe_url(self.id))
+            if self.runtime["state"] != "Deploying":
+                return
+            elapsetime = time.monotonic() - starttime
+            if elapsetime > timeout:
+                raise AssertionError("Timed out while waiting for the config of the pipe '{self.id}' to be deployed.")
+            time.sleep(1)
